@@ -39,11 +39,7 @@ class Account(BlockchainObject):
 
     type_id = 2
 
-    def __init__(
-        self,
-        *args,
-        **kwargs
-    ):
+    def __init__(self, *args, **kwargs):
         self.full = kwargs.pop("full", False)
         super().__init__(*args, **kwargs)
 
@@ -186,12 +182,7 @@ class AccountUpdate(dict, BlockchainInstance):
 
     """
 
-    def __init__(
-        self,
-        data,
-        *args,
-        **kwargs
-    ):
+    def __init__(self, data, *args, **kwargs):
         BlockchainInstance.__init__(self, *args, **kwargs)
         if isinstance(data, dict):
             super(AccountUpdate, self).__init__(data)
