@@ -50,11 +50,7 @@ class Amount(dict):
             Amount("1 USD") * 2
             Amount("15 GOLD") + Amount("0.5 GOLD")
     """
-    def __init__(
-        self,
-        *args,
-        **kwargs
-    ):
+    def __init__(self, *args, **kwargs):
         self["asset"] = {}
 
         amount = kwargs.get("amount", None)
@@ -169,6 +165,11 @@ class Amount(dict):
     def __int__(self):
         return int(self["amount"] * 10 ** self["asset"]["precision"])
 
+    def __neg__(self):
+        a = self.copy()
+        a["amount"] = -float(a)
+        return a
+
     def __add__(self, other):
         a = self.copy()
         if isinstance(other, Amount):
