@@ -1,4 +1,3 @@
-from peerplays.instance import shared_peerplays_instance
 from .exceptions import BetDoesNotExistException
 from .blockchainobject import BlockchainObject
 
@@ -7,13 +6,13 @@ class Bet(BlockchainObject):
     """ Read data about a Bet on the chain
 
         :param str identifier: Identifier
-        :param peerplays peerplays_instance: PeerPlays() instance to use when accesing a RPC
+        :param peerplays blockchain_instance: PeerPlays() instance to use when accesing a RPC
 
     """
     type_id = 22
 
     def refresh(self):
-        data = self.peerplays.rpc.get_object(self.identifier)
+        data = self.blockchain.rpc.get_object(self.identifier)
         if not data:
             raise BetDoesNotExistException(self.identifier)
         dict.__init__(self, data)
