@@ -17,9 +17,11 @@ from .rule import Rule
 from .bettingmarketgroup import BettingMarketGroup
 from .bettingmarket import BettingMarket
 from .bet import Bet
+from .genesisbalance import GenesisBalance
 
 from .exceptions import (
     AccountExistsException,
+    MissingKeyError
 )
 from .wallet import Wallet
 from .transactionbuilder import TransactionBuilder, ProposalBuilder
@@ -184,16 +186,6 @@ class PeerPlays(object):
     def prefix(self):
         return self.rpc.chain_params["prefix"]
 
-    def newWallet(self, pwd):
-        """ Create a new wallet. This method is basically only calls
-            :func:`peerplays.wallet.create`.
-
-            :param str pwd: Password to use for the new wallet
-            :raises peerplays.exceptions.WalletExists: if there is already a
-                wallet created
-        """
-        self.wallet.create(pwd)
-
     def set_default_account(self, account):
         """ Set the default account to be used
         """
@@ -267,6 +259,14 @@ class PeerPlays(object):
             # Append tot he default buffer
             self.txbuffer.appendOps(ops)
 
+        # The API that obtains the fee only allows to specify one particular
+        # fee asset for all operations in that transaction even though the
+        # blockchain itself could allow to pay multiple operations with
+        # different fee assets.
+        if "fee_asset" in kwargs and kwargs["fee_asset"]:
+            fee_asset = Asset(kwargs["fee_asset"], blockchain_instance=self)
+            self.txbuffer.set_fee_asset(fee_asset)
+
         # Add signing information, signer, sign and optionally broadcast
         if self.unsigned:
             # In case we don't want to sign anything
@@ -408,7 +408,7 @@ class PeerPlays(object):
             proposal_review,
             blockchain_instance=self,
             parent=parent,
-            **kwargs,
+            **kwargs
         )
         if parent:
             parent.appendOps(proposal)
@@ -578,9 +578,9 @@ class PeerPlays(object):
             memo_privkey = memo_key.get_private_key()
             # store private keys
             if storekeys:
-                # self.wallet.addPrivateKey(owner_privkey)
-                self.wallet.addPrivateKey(active_privkey)
-                self.wallet.addPrivateKey(memo_privkey)
+                # self.wallet.addPrivateKey(str(owner_privkey))
+                self.wallet.addPrivateKey(str(active_privkey))
+                self.wallet.addPrivateKey(str(memo_privkey))
         elif (owner_key and active_key and memo_key):
             active_pubkey = PublicKey(
                 active_key, prefix=self.prefix)
@@ -622,7 +622,7 @@ class PeerPlays(object):
             "fee": {"amount": 0, "asset_id": "1.3.0"},
             "registrar": registrar["id"],
             "referrer": referrer["id"],
-            "referrer_percent": referrer_percent * 100,
+            "referrer_percent": int(referrer_percent * 100),
             "name": account_name,
             'owner': {'account_auths': owner_accounts_authority,
                       'key_auths': owner_key_authority,
@@ -1030,7 +1030,7 @@ class PeerPlays(object):
                 account = config["default_account"]
         if not account:
             raise ValueError("You need to provide an account")
-        account = Account(account)
+        account = Account(account, blockchain_instance=self)
         is_key = approver and approver[:3] == self.prefix
         if not approver and not is_key:
             approver = account
@@ -1317,6 +1317,10 @@ class PeerPlays(object):
             "prefix": self.prefix
         }
 
+        # Do not try to update status of it doesn't change it on the chain
+        if event["status"] == status:
+            status = None
+
         if event_group_id:
             if event_group_id[0] == "1":
                 # Test if object exists
@@ -1365,6 +1369,10 @@ class PeerPlays(object):
         account = Account(account)
         event = Event(event_id)
 
+        # Do not try to update status of it doesn't change it on the chain
+        if event["status"] == status:
+            status = None
+
         op = operations.Event_update_status(**{
             "fee": {"amount": 0, "asset_id": "1.3.0"},
             "event_id": event["id"],
@@ -1530,6 +1538,10 @@ class PeerPlays(object):
         account = Account(account, blockchain_instance=self)
         bmg = BettingMarketGroup(betting_market_group_id)
 
+        # Do not try to update status of it doesn't change it on the chain
+        if bmg["status"] == status:
+            status = None
+
         op_data = {
             "fee": {"amount": 0, "asset_id": "1.3.0"},
             "betting_market_group_id": bmg["id"],
