@@ -23,10 +23,9 @@ class ProposalBuilder:
             supposed to expire
         :param int proposal_review: Number of seconds for review of the
             proposal
-        :param peerplays.transactionbuilder.TransactionBuilder: Specify
+        :param .transactionbuilder.TransactionBuilder: Specify
             your own instance of transaction builder (optional)
-        :param peerplays.peerplays.PeerPlays blockchain_instance: PeerPlays
-            instance
+        :param instance blockchain_instance: Blockchain instance
     """
     def __init__(
         self,
@@ -138,11 +137,18 @@ class TransactionBuilder(dict):
     ):
         BlockchainInstance.__init__(self, **kwargs)
         self.clear()
-        if not isinstance(tx, dict):
-            raise ValueError("Invalid TransactionBuilder Format")
-        super(TransactionBuilder, self).__init__(tx)
-        # Do we need to reconstruct the tx from self.ops?
-        self._require_reconstruction = True
+        if tx and isinstance(tx, dict):
+            super(TransactionBuilder, self).__init__(tx)
+            # Load operations
+            self.ops = tx["operations"]
+            self._require_reconstruction = False
+        else:
+            self._require_reconstruction = True
+            self.set_fee_asset(kwargs.get("fee_asset", None))
+        self.set_expiration(kwargs.get("expiration", self.blockchain.expiration) or 30)
+
+    def set_expiration(self, p):
+        self.expiration = p
 
     def is_empty(self):
         return not (len(self.ops) > 0)
@@ -199,17 +205,11 @@ class TransactionBuilder(dict):
             self.ops.append(ops)
         self._set_require_reconstruction()
 
-    def appendSigner(self, account, permission):
-        """ Try to obtain the wif key from the wallet by telling which account
+    def appendSigner(self, accounts, permission):
+        """ Try to obtain the wif key from the wallet by telling which accounts
             and permission is supposed to sign the transaction
         """
-        assert permission in ["active", "owner"], "Invalid permission"
-        account = Account(account, blockchain_instance=self.blockchain)
-        required_treshold = account[permission]["weight_threshold"]
-
-        if self.blockchain.wallet.locked():
-            raise WalletLocked()
-
+        # Let's define a helper function for recursion
         def fetchkeys(account, perm, level=0):
             if level > 2:
                 return []
@@ -231,24 +231,35 @@ class TransactionBuilder(dict):
 
             return r
 
-        if account not in self.signing_accounts:
-            # is the account an instance of public key?
-            if isinstance(account, PublicKey):
-                self.wifs.add(
-                    self.blockchain.wallet.getPrivateKeyForPublicKey(
-                        str(account)
-                    )
-                )
-            else:
-                account = Account(account, blockchain_instance=self.blockchain)
-                required_treshold = account[permission]["weight_threshold"]
-                keys = fetchkeys(account, permission)
-                if permission != "owner":
-                    keys.extend(fetchkeys(account, "owner"))
-                for x in keys:
-                    self.wifs.add(x[0])
+        assert permission in ["active", "owner"], "Invalid permission"
+        if self.blockchain.wallet.locked():
+            raise WalletLocked()
+        if not isinstance(accounts, (list, tuple, set)):
+            accounts = [accounts]
 
-            self.signing_accounts.append(account)
+        for account in accounts:
+            # Now let's actually deal with the accounts
+            if account not in self.signing_accounts:
+                # is the account an instance of public key?
+                if isinstance(account, PublicKey):
+                    self.wifs.add(
+                        self.blockchain.wallet.getPrivateKeyForPublicKey(
+                            str(account)
+                        )
+                    )
+                # ... or should we rather obtain the keys from an account name
+                else:
+                    account = Account(account, blockchain_instance=self.blockchain)
+                    required_treshold = account[permission]["weight_threshold"]
+                    keys = fetchkeys(account, permission)
+                    # If we couldn't find an active key, let's try overwrite it
+                    # with an owner key
+                    if not keys and permission != "owner":
+                        keys.extend(fetchkeys(account, "owner"))
+                    for x in keys:
+                        self.wifs.add(x[0])
+
+                self.signing_accounts.append(account)
 
     def appendWif(self, wif):
         """ Add a wif that should be used for signing of the transaction.
@@ -260,6 +271,17 @@ class TransactionBuilder(dict):
             except:
                 raise InvalidWifError
 
+    def set_fee_asset(self, fee_asset):
+        """ Set asset to fee
+        """
+        from .amount import Asset
+        if isinstance(fee_asset, Asset):
+            self.fee_asset_id = fee_asset["id"]
+        elif fee_asset:
+            self.fee_asset_id = fee_asset
+        else:
+            self.fee_asset_id = "1.3.0"
+
     def constructTx(self):
         """ Construct the actual transaction and store it in the class's dict
             store
@@ -276,9 +298,12 @@ class TransactionBuilder(dict):
                 # otherwise, we simply wrap ops into Operations
                 ops.extend([Operation(op)])
 
-        # We no wrap everything into an actual transaction
-        ops = transactions.addRequiredFees(self.blockchain.rpc, ops)
-        expiration = transactions.formatTimeFromNow(self.blockchain.expiration)
+        # We now wrap everything into an actual transaction
+        ops = transactions.addRequiredFees(self.blockchain.rpc, ops,
+                                           asset_id=self.fee_asset_id)
+        expiration = transactions.formatTimeFromNow(
+            self.expiration or self.blockchain.expiration
+        )
         ref_block_num, ref_block_prefix = transactions.getBlockParams(
             self.blockchain.rpc)
         self.tx = Signed_Transaction(
@@ -287,11 +312,11 @@ class TransactionBuilder(dict):
             expiration=expiration,
             operations=ops
         )
-        super(TransactionBuilder, self).__init__(self.tx.json())
+        super(TransactionBuilder, self).update(self.tx.json())
         self._unset_require_reconstruction()
 
     def sign(self):
-        """ Sign a provided transaction witht he provided key(s)
+        """ Sign a provided transaction with the provided key(s)
 
             :param dict tx: The transaction to be signed and returned
             :param string wifs: One or many wif keys to use for signing
@@ -332,6 +357,7 @@ class TransactionBuilder(dict):
 
         signedtx.sign(self.wifs, chain=self.blockchain.rpc.chain_params)
         self["signatures"].extend(signedtx.json().get("signatures"))
+        return signedtx
 
     def verify_authority(self):
         """ Verify the authority of the signed transaction
@@ -343,7 +369,7 @@ class TransactionBuilder(dict):
             raise e
 
     def broadcast(self):
-        """ Broadcast a transaction to the PeerPlays network
+        """ Broadcast a transaction to the blockchain network
 
             :param tx tx: Signed transaction to broadcast
         """
@@ -372,8 +398,9 @@ class TransactionBuilder(dict):
                     ret, api="network_broadcast")
         except Exception as e:
             raise e
+        finally:
+            self.clear()
 
-        self.clear()
         return ret
 
     def clear(self):
@@ -386,7 +413,7 @@ class TransactionBuilder(dict):
         self["expiration"] = None
         super(TransactionBuilder, self).__init__({})
 
-    def addSigningInformation(self, account, permission):
+    def addSigningInformation(self, accounts, permission):
         """ This is a private method that adds side information to a
             unsigned/partial transaction in order to simplify later
             signing (e.g. for multisig or coldstorage)
@@ -396,36 +423,44 @@ class TransactionBuilder(dict):
         self.constructTx()
         self["blockchain"] = self.blockchain.rpc.chain_params
 
-        if isinstance(account, PublicKey):
+        if isinstance(accounts, PublicKey):
             self["missing_signatures"] = [
-                str(account)
+                str(accounts)
             ]
         else:
-            accountObj = Account(account)
-            authority = accountObj[permission]
-            # We add a required_authorities to be able to identify
-            # how to sign later. This is an array, because we
-            # may later want to allow multiple operations per tx
-            self.update({"required_authorities": {
-                accountObj["name"]: authority
-            }})
-            for account_auth in authority["account_auths"]:
-                account_auth_account = Account(account_auth[0])
-                self["required_authorities"].update({
-                    account_auth[0]: account_auth_account.get(permission)
-                })
+            if not isinstance(accounts, list):
+                accounts = [accounts]
+            for account in accounts:
+                accountObj = Account(account)
+                authority = accountObj[permission]
+                # We add a required_authorities to be able to identify
+                # how to sign later. This is an array, because we
+                # may later want to allow multiple operations per tx
+                if "required_authorities" not in self:
+                    self["required_authorities"] = dict()
+                if "missing_signatures" not in self:
+                    self["missing_signatures"] = list()
 
-            # Try to resolve required signatures for offline signing
-            self["missing_signatures"] = [
-                x[0] for x in authority["key_auths"]
-            ]
-            # Add one recursion of keys from account_auths:
-            for account_auth in authority["account_auths"]:
-                account_auth_account = Account(account_auth[0])
-                self["missing_signatures"].extend(
-                    [x[0]
-                     for x in account_auth_account[permission]["key_auths"]]
-                )
+                self["required_authorities"].update({
+                    accountObj["name"]: authority
+                })
+                for account_auth in authority["account_auths"]:
+                    account_auth_account = Account(account_auth[0])
+                    self["required_authorities"].update({
+                        account_auth[0]: account_auth_account.get(permission)
+                    })
+
+                # Try to resolve required signatures for offline signing
+                self["missing_signatures"].extend([
+                    x[0] for x in authority["key_auths"]
+                ])
+                # Add one recursion of keys from account_auths:
+                for account_auth in authority["account_auths"]:
+                    account_auth_account = Account(account_auth[0])
+                    self["missing_signatures"].extend([
+                        x[0]
+                        for x in account_auth_account[permission]["key_auths"]]
+                    )
 
     def appendMissingSignatures(self):
         """ Store which accounts/keys are supposed to sign the transaction
